API Reference# This section covers the public functions and modules available in egxpy. Download Module# egxpy.download.get_OHLCV_data fetches close prices for a single ticker egxpy.download.get_EGXdata Fetches Historical close prices data for EGX stocks egxpy.download.get_EGX_intraday_data Fetches intraday data for EGX stocks